@@ -48,14 +48,28 @@ def parse_asdu(trama):
 
 
 class ProtocolException(Exception):
-    pass
+
+    message = 'Protocol Exception'
+
+    def __init__(self, message):
+        self.message = 'Protocol Exception: {}'.format(message)
+
+    def __str__(self):
+        return self.message
 
 
 class IntegrationPeriodNotAvailable(Exception):
-    pass
+
+    def __str__(self):
+        return 'Integration Period Not available'
 
 
 class RequestedASDUTypeNotAvailable(Exception):
+
+    def __str__(self):
+        return 'Requested ASDU Type Not Available'
+
+class ASDUDirectionUnknown(Exception):
     pass
 
 
@@ -115,12 +129,15 @@ class AppLayer(with_metaclass(ABCMeta)):
             elif asdu_resp.causa_tm == 0x0E:
                 logger.error("Requested ASDU-type not available")
                 raise RequestedASDUTypeNotAvailable()
-            elif asdu_resp.causa_tm == 0x12:
-                logger.error("Requested integration period not available")
-                raise IntegrationPeriodNotAvailable()
+            elif asdu_resp.causa_tm == 0x10:
+                logger.error("ASDU Direction especification unknown")
+                raise ASDUDirectionUnknown()
             elif asdu_resp.causa_tm == 0x11:
                 logger.error("Requested information object not available")
                 raise IntegrationPeriodNotAvailable()
+            elif asdu_resp.causa_tm == 0x12:
+                logger.error("Requested integration period not available")
+                raise IntegrationPeriodNotAvailable()
             else:
                 raise Exception('ERROR: Transmission cause unknown: {}'.format(asdu_resp.causa_tm))
 
